@@ -1,27 +1,28 @@
 package App::Prove;
 
 use strict;
-use vars qw($VERSION @ISA);
+use warnings;
 
-use TAP::Object ();
-use TAP::Harness;
-use TAP::Parser::Utils qw( split_shell );
+use TAP::Harness::Env;
+use Text::ParseWords qw(shellwords);
 use File::Spec;
 use Getopt::Long;
 use App::Prove::State;
 use Carp;
 
+use base 'TAP::Object';
+
 =head1 NAME
 
 App::Prove - Implements the C<prove> command.
 
 =head1 VERSION
 
-Version 3.27
+Version 3.31
 
 =cut
 
-$VERSION = '3.27';
+our $VERSION = '3.31';
 
 =head1 DESCRIPTION
 
@@ -51,8 +52,6 @@ use constant PLUGINS => 'App::Prove::Plugin';
 my @ATTR;
 
 BEGIN {
-    @ISA = qw(TAP::Object);
-
     @ATTR = qw(
       archive argv blib show_count color directives exec failures comments
       formatter harness includes modules plugins jobs lib merge parse quiet
@@ -89,7 +88,6 @@ sub _initialize {
     for my $key (@is_array) {
         $self->{$key} = [];
     }
-    $self->{harness_class} = 'TAP::Harness';
 
     for my $attr (@ATTR) {
         if ( exists $args->{$attr} ) {
@@ -99,13 +97,6 @@ sub _initialize {
         }
     }
 
-    my %env_provides_default = (
-        HARNESS_TIMER => 'timer',
-    );
-
-    while ( my ( $env, $attr ) = each %env_provides_default ) {
-        $self->{$attr} = 1 if $ENV{$env};
-    }
     $self->state_class('App::Prove::State');
     return $self;
 }
@@ -387,8 +378,9 @@ sub _get_args {
         }
         $args{rules} = { par => [@rules] };
     }
+    $args{harness_class} = $self->{harness_class} if $self->{harness_class};
 
-    return ( \%args, $self->{harness_class} );
+    return \%args;
 }
 
 sub _find_module {
@@ -534,8 +526,8 @@ sub _get_tests {
 }
 
 sub _runtests {
-    my ( $self, $args, $harness_class, @tests ) = @_;
-    my $harness = $harness_class->new($args);
+    my ( $self, $args, @tests ) = @_;
+    my $harness = TAP::Harness::Env->create($args);
 
     my $state = $self->state_manager;
 
@@ -574,8 +566,6 @@ sub _get_switches {
         push @switches, '-w';
     }
 
-    push @switches, split_shell( $ENV{HARNESS_PERL_SWITCHES} );
-
     return @switches ? \@switches : ();
 }
 
