@@ -3,7 +3,7 @@ package TAP::Base;
 use strict;
 use warnings;
 
-use parent 'TAP::Object';
+use base 'TAP::Object';
 
 =head1 NAME
 
@@ -12,11 +12,11 @@ and L<TAP::Harness>
 
 =head1 VERSION
 
-Version 3.29
+Version 3.31
 
 =cut
 
-our $VERSION = '3.29';
+our $VERSION = '3.31';
 
 use constant GOT_TIME_HIRES => do {
     eval 'use Time::HiRes qw(time);';
@@ -27,7 +27,7 @@ use constant GOT_TIME_HIRES => do {
 
     package TAP::Whatever;
 
-    use parent 'TAP::Base';
+    use base 'TAP::Base';
 
     # ... later ...
     
