@@ -6,7 +6,7 @@ use File::Spec;
 use File::Path;
 use Carp;
 
-use parent 'TAP::Formatter::Console::Session';
+use base 'TAP::Formatter::Console::Session';
 
 use constant WIDTH => 72;    # Because Eric says
 
@@ -41,11 +41,11 @@ TAP::Formatter::Console::ParallelSession - Harness output delegate for parallel
 
 =head1 VERSION
 
-Version 3.29
+Version 3.31
 
 =cut
 
-our $VERSION = '3.29';
+our $VERSION = '3.31';
 
 =head1 DESCRIPTION
 
