@@ -3,7 +3,7 @@ package TAP::Parser::Result::Plan;
 use strict;
 use warnings;
 
-use parent 'TAP::Parser::Result';
+use base 'TAP::Parser::Result';
 
 =head1 NAME
 
@@ -11,11 +11,11 @@ TAP::Parser::Result::Plan - Plan result token.
 
 =head1 VERSION
 
-Version 3.29
+Version 3.31
 
 =cut
 
-our $VERSION = '3.29';
+our $VERSION = '3.31';
 
 =head1 DESCRIPTION
 
