@@ -6,7 +6,7 @@ use warnings;
 use TAP::Parser::IteratorFactory  ();
 use TAP::Parser::Iterator::Stream ();
 
-use parent 'TAP::Parser::SourceHandler';
+use base 'TAP::Parser::SourceHandler';
 
 TAP::Parser::IteratorFactory->register_handler(__PACKAGE__);
 
@@ -16,11 +16,11 @@ TAP::Parser::SourceHandler::File - Stream TAP from a text file.
 
 =head1 VERSION
 
-Version 3.29
+Version 3.31
 
 =cut
 
-our $VERSION = '3.29';
+our $VERSION = '3.31';
 
 =head1 SYNOPSIS
 
